@@ -4,4 +4,4 @@ mod primes;
 mod rational;
 
 mod wigner_3j;
-pub use self::wigner_3j::{wigner_3j, clebsch_gordan};
+pub use self::wigner_3j::{wigner_3j, clebsch_gordan, clear_wigner_3j_cache};
