@@ -227,7 +227,7 @@ impl std::fmt::Debug for PrimeFactorization {
 
 impl PrimeFactorization {
     /// Compute the prime factorization of the integer `n`
-    pub fn new(n: i32) -> PrimeFactorization {
+    fn new(n: i32) -> PrimeFactorization {
         let sign = match n.cmp(&0) {
             Ordering::Equal => {
                 return PrimeFactorization {
@@ -266,6 +266,16 @@ impl PrimeFactorization {
         };
     }
 
+    /// Get the prime factorization of 1
+    pub fn one() -> PrimeFactorization {
+        PrimeFactorization::new(1)
+    }
+
+    /// Get the prime factorization of -1
+    pub fn minus_one() -> PrimeFactorization {
+        PrimeFactorization::new(-1)
+    }
+
     /// trim factors to contain no trailing zeros, except if we are representing
     /// the number -1 or 1, in which case the factors will contain exactly one
     /// zero.
